summaryrefslogtreecommitdiffstats
path: root/lib/kofficeui/KoPageLayoutSize.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficeui/KoPageLayoutSize.h')
-rw-r--r--lib/kofficeui/KoPageLayoutSize.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/kofficeui/KoPageLayoutSize.h b/lib/kofficeui/KoPageLayoutSize.h
index f1f4f358..d917b349 100644
--- a/lib/kofficeui/KoPageLayoutSize.h
+++ b/lib/kofficeui/KoPageLayoutSize.h
@@ -41,14 +41,14 @@ class KoPageLayoutSize : public TQWidget {
public:
/**
* Contructor
* @param tqparent the tqparent widget
* @param tqlayout the page tqlayout that this widget should be initialzed with.
* @param unit the unit-type (mm/cm/inch) that the dialog should show
* @param columns the KoColumns (amout of columns) that the preview should be initialized with
* @param unitChooser if true a combobox with the unit-type is shown for the user to change
* @param enableBorders if true enable the user to change the margins (aka borders) of the page
*/
- KoPageLayoutSize(TQWidget *tqparent, const KoPageLayout& tqlayout, KoUnit::Unit unit,
+ KoPageLayoutSize(TQWidget *parent, const KoPageLayout& tqlayout, KoUnit::Unit unit,
const KoColumns& columns, bool unitChooser, bool enableBorders);
/**
@@ -41,14 +41,14 @@ class KoPageLayoutSize : public TQWidget {
/**
* Contructor
- * @param tqparent the tqparent widget
+ * @param parent the parent widget
* @param tqlayout the page tqlayout that this widget should be initialzed with.
* @param unit the unit-type (mm/cm/inch) that the dialog should show